/**
 * project: Mobile Datacommunication
 * file: StringServerImpl.java
 * date: 2003-03-09
 */

package com.maretzke.mobile.rmi;

// import RMI related stuff
import java.rmi.Naming;
import java.rmi.RemoteException;
import java.rmi.RMISecurityManager;
import java.rmi.server.UnicastRemoteObject;

/**
 * Server side implementation of com.maretzke.mobile.rmi.StringServer interface.
 * 
 * @author Michael Maretzke
 * @version 1.0
 */
public class StringServerImpl extends UnicastRemoteObject implements StringServer {
  /**
   * Default constructor
   * @exception RemoteException thrown if something during remote communication went wrong
   */
  public StringServerImpl() throws RemoteException {
    super();
  }
  
  /**
   * This method returns the input parameter
   * @param input string to return 
   * @exception RemoteException thrown if something during remote communication went wrong
   */
  public String echo(String input) throws RemoteException {
    return input;
  }

  /**
   * Main method of StringServerImpl
   * @param args command line input parameters
   */	
  public static void main(String args[]) {
  
    // Create and install a security manager
    if (System.getSecurityManager() == null) {
      System.setSecurityManager(new RMISecurityManager());
    }

    try {
      // create an instance of this class
      StringServerImpl ssref = new StringServerImpl();

      // bind this object instance to the name "StringServer"
      Naming.rebind("//localhost/StringServer", ssref);

      System.out.println("StringServer bound in registry");
    } 
    catch (RemoteException re) {
      System.out.println("Remoteexception: " + re);
      re.printStackTrace();
    }
    catch (Exception e) {
      System.out.println("StringServerImpl err: " + e);
      e.printStackTrace();
    }
  }
}
  
  
